package org.blue.club.controller;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.blue.club.annotation.Auth;
import org.blue.club.annotation.DescriptionType;
import org.blue.club.annotation.PermissionDescription;
import org.blue.club.entities.dto.club.req.CreateClubRequest;
import org.blue.club.entities.vo.data.ClubVo;
import org.blue.club.services.ClubServices;
import org.mmga.spring.boot.starter.entities.PagerData;
import org.mmga.spring.boot.starter.entities.Result;
import org.springframework.web.bind.annotation.*;

@RestController
@Tag(name = "社团相关接口")
@RequestMapping("/api/club")
@RequiredArgsConstructor
public class ClubController {
    private final ClubServices clubServices;

    @GetMapping("/")
    @Operation(description = "分页获取社团")
    public Result<PagerData<ClubVo>> getClubs(@Schema(description = "分页数据第几页") @RequestParam Integer page, @Schema(description = "分页数据每页数据量") @RequestParam Integer num) {
        return clubServices.getClubs(page, num);
    }

    @Operation(description = "创建社团")
    @Auth(permissions = {@PermissionDescription(3)})
    @PutMapping("/create")
    public Result<ClubVo> createClub(@RequestBody CreateClubRequest request) {
        return clubServices.createClub(request);
    }

    @Operation(description = "向社团添加用户")
    @PutMapping("/user/add")
    @Auth(permissions = {@PermissionDescription(3), @PermissionDescription(value = 2, type = DescriptionType.CLUB)})
    public Result<Boolean> addUserToClub() {
        return Result.failed();
    }
}
