package org.blue.club.services;

import com.mybatisflex.core.paginate.Page;
import com.mybatisflex.core.query.QueryCondition;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.blue.club.dao.ClubDao;
import org.blue.club.entities.dto.club.req.CreateClubRequest;
import org.blue.club.entities.vo.data.ClubVo;
import org.mmga.spring.boot.starter.entities.PagerData;
import org.mmga.spring.boot.starter.entities.Result;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;

import static org.blue.club.entities.vo.data.table.ClubVoTableDef.CLUB_VO;

@Service
@RequiredArgsConstructor
@Slf4j
public class ClubServices {
    private final ClubDao clubDao;

    public Result<PagerData<ClubVo>> getClubs(Integer page, Integer num) {
        Page<ClubVo> data = clubDao.paginate(page, num, QueryCondition.createEmpty());
        return Result.success(new PagerData<>(data.getTotalRow(), data.getRecords()));
    }

    public Result<ClubVo> createClub(CreateClubRequest request) {
        if (clubDao.selectCountByCondition(CLUB_VO.NAME.eq(clubDao)) > 0)
            return Result.failed(HttpStatus.CONFLICT, "社团名称已存在！");
        ClubVo clubVo = new ClubVo();
        clubVo.setName(request.name());
        return Result.success(clubVo);
    }
}
